summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/enum.h
diff options
context:
space:
mode:
authorMatthew Cline <zelgadis@sourceforge.net>2009-11-06 02:07:47 -0800
committerMatthew Cline <zelgadis@sourceforge.net>2009-11-06 02:13:04 -0800
commit634346b199170aa7aadf3055938363395f3507b2 (patch)
tree9aeaf3ed03a17b5e6c28fcbcf7cd1067a4ecfe9e /crawl-ref/source/enum.h
parent95fae39c5ba6c345d458ee828ae732faba7d8a82 (diff)
downloadcrawl-ref-634346b199170aa7aadf3055938363395f3507b2.tar.gz
crawl-ref-634346b199170aa7aadf3055938363395f3507b2.zip
Monster name flags fixups
Rename MF_NAME_NO_THE to MF_NAME_ADJECTIVE, since that's what it does. Make description_level_type apply properly to monsters with MF_NAME_FOO flags set.
Diffstat (limited to 'crawl-ref/source/enum.h')
-rw-r--r--crawl-ref/source/enum.h2
1 files changed, 1 insertions, 1 deletions
diff --git a/crawl-ref/source/enum.h b/crawl-ref/source/enum.h
index 961eedf183..b995c6416e 100644
--- a/crawl-ref/source/enum.h
+++ b/crawl-ref/source/enum.h
@@ -2149,7 +2149,7 @@ enum monster_flag_type
// Yredelemnul's power
MF_NAME_SUFFIX = 0x10000, // mname is a suffix.
- MF_NAME_NO_THE = 0x20000, // mname is a prefix with no "the"
+ MF_NAME_ADJECTIVE = 0x20000, // mname is an adjective.
// between it and the monster type name.
MF_NAME_REPLACE = 0x30000, // mname entirely replaces normal monster
// name.